use strict;
package ASCOPE::Article::Collection::Constants;

# $Id: Constants.pm,v 1.2 2004/07/23 12:59:59 asc Exp $

=head1 NAME

ASCOPE::Article::Collection::Constants - constant variables

=head1 SYNOPSIS

  # Import all the constants exported
  # by ASCOPE::Article::Collection::Constants::Rels
  # into the current package.

  use ASCOPE::Article::Collection::Constants qw (:rels);

=head1 DESCRIPTION

Import constant variables

=cut

sub import {
    my $self = shift;
    
    #
    
    my @sets  = ();
    my $debug = 0;
    
    foreach (@_) {
	if ($_ =~ /^:(.*)/) {
	    push @sets, $1;
	}
	
	elsif (/^\+(.*)/) {
	    
	    if ($1 eq "debug") {
		$debug = 1;
	    }
	}
	
	else { next; }
    }
    
    #
    
    foreach my $set (@sets) {
	
	# paranoia / 
	# will destroy ya
	$set =~ s/:://g;
	
	my $package = join("::",__PACKAGE__,ucfirst(lc($set)));
	my $caller  = caller;
	
	print STDERR "* $caller wants to import $set\n"
	    if ($debug);
	
	eval "require $package;";
	die $@ if ($@);
	
	no strict 'refs';
	
	foreach my $constant (@{$package."::EXPORT_OK"}) {
	    *{join("::",$caller,$constant)} = \&{join("::",$package,$constant)};
	}
    }
}

=head1 VERSION

0.1

=head1 DATE

$Date: 2004/07/23 12:59:59 $

=head1 AUTHOR

Aaron Straup Cope E<lt>ascope@cpan.orgE<gt>

=head1 SEE ALSO

L<ASCOPE::Article::Collection>

=head1 LICENSE

Copyright (c) 2004 Aaron Straup Cope. All rights reserved.

This is free software, you may use it and distribute it under the
same terms as Perl itself.

=cut

return 1;
